--[[

$Revision: 306 $

(C) Copyright 2009 Bethink (bethink at naef dot com)
See LICENSE.txt for license terms.

]]


----------------------------------------------------------------------
-- Initialization

BossNotesRulesBigWigsDisplay = BossNotesRules:NewModule("BigWigs",
		"AceEvent-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("BossNotes")


----------------------------------------------------------------------
-- Core handlers

function BossNotesRulesBigWigsDisplay:OnInitialize ()
	self.supported = IsAddOnLoaded("BigWigs_Core")
	if self.supported then
		self.mod = BigWigs:NewBoss("Boss Notes Rules", "")
		self.mod.db = { }
		self.mod.db.profile = { }
		self.barTexts = { }
	end
end

function BossNotesRulesBigWigsDisplay:OnEnable ()
	if self.supported then
		self:RegisterMessage("BOSS_NOTES_RULES_NOTIFICATION")
		self:RegisterMessage("BOSS_NOTES_RULES_TIMER_START")
		self:RegisterMessage("BOSS_NOTES_RULES_TIMER_STOP")
	end
end

function BossNotesRulesBigWigsDisplay:OnDisable ()
end


----------------------------------------------------------------------
-- Event handlers

function BossNotesRulesBigWigsDisplay:BOSS_NOTES_RULES_NOTIFICATION (
		message, id, text, important, spellId)
	local sound
	if important then
		self.mod.db.profile[id] = BigWigs.C.MESSAGE + BigWigs.C.EMPHASIZE + BigWigs.C.FLASHSHAKE
		self.mod:LocalMessage(id, text, "Personal", spelId)
		self.mod:FlashShake(id)
	else
		self.mod.db.profile[id] = BigWigs.C.MESSAGE
		self.mod:Message(id, text, "Urgent", spellId, "Alarm")
	end
end

function BossNotesRulesBigWigsDisplay:BOSS_NOTES_RULES_TIMER_START (
		message, id, text, duration, spellId)
	-- Stop the previous bar, if any.
	if self.barTexts[id] then
		self:SendMessage("BigWigs_StopBar", self.mod, self.barTexts[id])
		self.barTexts[id] = nil
	end
	
	-- Start the bar.
	self.barTexts[id] = text
	self.mod.db.profile[id] = BigWigs.C.BAR
	self.mod:Bar(id, text, duration, spellId)
end

function BossNotesRulesBigWigsDisplay:BOSS_NOTES_RULES_TIMER_STOP (
		message, id)
	if self.barTexts[id] then
		self:SendMessage("BigWigs_StopBar", self.mod, self.barTexts[id])
		self.barTexts[id] = nil
	end
end


----------------------------------------------------------------------
-- Display Module

-- Mark this module as a display module.
BossNotesRulesBigWigsDisplay.BOSS_NOTES_RULES_DISPLAY_MODULE = true

-- Returns information about this display module.
function BossNotesRulesBigWigsDisplay:GetDisplayInfo ()
	return "bigWigs", L["BIGWIGS_DISPLAY"], L["BIGWIGS_DISPLAY_DESC"]
end
